import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_ec2._jsii
import aws_cdk.aws_ecs._jsii
import aws_cdk.aws_ecs_patterns._jsii
import aws_cdk.aws_efs._jsii
import aws_cdk.aws_elasticloadbalancingv2._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_logs._jsii
import aws_cdk.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "cdk-apisix", "0.0.32", __name__[0:-6], "cdk-apisix@0.0.32.jsii.tgz"
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
